@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from datetime import date, datetime
-from typing import List, Optional, Union
+from typing import Optional, Union
 from uuid import UUID
 
 from polyfactory.factories import DataclassFactory
@@ -11,8 +11,8 @@ from polyfactory.pytest_plugin import register_fixture
 class Person:
     id: UUID
     name: str
-    hobbies: Optional[List[str]]
-    nicks: List[str]
+    hobbies: Optional[list[str]]
+    nicks: list[str]
     age: Union[float, int]
     birthday: Union[datetime, date]
 
