@@ -1,13 +1,12 @@
 from .exceptions import ConfigurationException
 from .factories import BaseFactory
-from .fields import Fixture, Ignore, PostGenerated, Require, Use
+from .fields import Ignore, PostGenerated, Require, Use
 from .persistence import AsyncPersistenceProtocol, SyncPersistenceProtocol
 
 __all__ = (
     "AsyncPersistenceProtocol",
     "BaseFactory",
     "ConfigurationException",
-    "Fixture",
     "Ignore",
     "PostGenerated",
     "Require",
