@@ -1,9 +1,22 @@
 from __future__ import annotations
 
+from collections.abc import Collection, Mapping
 from datetime import date, datetime
-from typing import TYPE_CHECKING, Annotated, Any, Callable, ClassVar, Generic, Protocol, TypeVar, Union
+from typing import (
+    TYPE_CHECKING,
+    Annotated,
+    Any,
+    Callable,
+    ClassVar,
+    Generic,
+    Protocol,
+    TypeVar,
+    Union,
+)
 
-from polyfactory.exceptions import MissingDependencyException, ParameterException
+from sqlalchemy.util.langhelpers import duck_type_collection
+
+from polyfactory.exceptions import ConfigurationException, MissingDependencyException, ParameterException
 from polyfactory.factories.base import BaseFactory
 from polyfactory.field_meta import Constraints, FieldMeta
 from polyfactory.persistence import AsyncPersistenceProtocol, SyncPersistenceProtocol
@@ -14,7 +27,7 @@ try:
     from sqlalchemy.dialects import mssql, mysql, postgresql, sqlite
     from sqlalchemy.exc import NoInspectionAvailable
     from sqlalchemy.ext.associationproxy import AssociationProxy
-    from sqlalchemy.orm import InstanceState, Mapper
+    from sqlalchemy.orm import InstanceState, Mapper, RelationshipProperty
 except ImportError as e:
     msg = "sqlalchemy is not installed"
     raise MissingDependencyException(msg) from e
@@ -203,6 +216,60 @@ class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
 
         return annotation
 
+    @classmethod
+    def get_type_from_collection_class(
+        cls,
+        collection_class: type[Collection[Any]] | Callable[[], Collection[Any]],
+        entity_class: Any,
+    ) -> type[Any]:
+        annotation: type[Any]
+
+        if isinstance(collection_class, type):
+            if issubclass(collection_class, Mapping):
+                annotation = dict[Any, entity_class]
+            else:
+                if not (duck_typed_as := duck_type_collection(collection_class)):
+                    msg = f"Cannot infer type from collection_class {collection_class}"
+                    raise ConfigurationException(
+                        msg,
+                    )
+
+                annotation = duck_typed_as[entity_class]  # pyright: ignore[reportIndexIssue]
+        else:
+            annotation = dict[Any, entity_class]
+
+        return annotation
+
+    @classmethod
+    def _get_relationship_type(cls, relationship: RelationshipProperty[Any]) -> type:
+        class_ = relationship.entity.class_
+        annotation: type
+
+        if relationship.uselist:
+            collection_class = relationship.collection_class
+            if collection_class is None:
+                annotation = list[class_]  # type: ignore[valid-type]
+            else:
+                annotation = cls.get_type_from_collection_class(collection_class, class_)
+        else:
+            annotation = class_
+
+        return annotation
+
+    @classmethod
+    def _get_association_proxy_type(cls, table: Mapper, proxy: AssociationProxy) -> type | None:
+        target_collection = table.relationships.get(proxy.target_collection)
+        if not target_collection:
+            return None
+
+        target_class = target_collection.entity.class_
+        target_attr = getattr(target_class, proxy.value_attr)
+        if not target_attr:
+            return None
+
+        class_ = target_attr.entity.class_
+        return class_ if not target_collection.uselist else list[class_]  # type: ignore[valid-type]
+
     @classmethod
     def get_model_fields(cls) -> list[FieldMeta]:
         fields_meta: list[FieldMeta] = []
@@ -218,30 +285,27 @@ class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
         )
         if cls.__set_relationships__:
             for name, relationship in table.relationships.items():
-                class_ = relationship.entity.class_
-                annotation = class_ if not relationship.uselist else list[class_]  # type: ignore[valid-type]
+                annotation = cls._get_relationship_type(relationship)
                 fields_meta.append(
                     FieldMeta.from_type(
                         name=name,
                         annotation=annotation,
-                    ),
+                    )
                 )
         if cls.__set_association_proxy__:
             for name, attr in table.all_orm_descriptors.items():
                 if isinstance(attr, AssociationProxy):
-                    target_collection = table.relationships.get(attr.target_collection)
-                    if target_collection:
-                        target_class = target_collection.entity.class_
-                        target_attr = getattr(target_class, attr.value_attr)
-                        if target_attr:
-                            class_ = target_attr.entity.class_
-                            annotation = class_ if not target_collection.uselist else list[class_]  # type: ignore[valid-type]
-                            fields_meta.append(
-                                FieldMeta.from_type(
-                                    name=name,
-                                    annotation=annotation,
-                                )
+                    # Read-only proxies derive from the underlying relationship and shouldn't be set directly.
+                    if not getattr(attr, "creator", None):
+                        continue
+
+                    if annotation := cls._get_association_proxy_type(table, attr):  # type: ignore[assignment]
+                        fields_meta.append(
+                            FieldMeta.from_type(
+                                name=name,
+                                annotation=annotation,
                             )
+                        )
 
         return fields_meta
 
