@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Any, Callable, Dict, Generic, TypeVar
+from typing import Any, Callable, Generic, TypeVar
 
 import pytest
 
@@ -24,7 +24,7 @@ def test_provider_map_with_any() -> None:
 
     class FooFactory(DataclassFactory[Foo]):
         @classmethod
-        def get_provider_map(cls) -> Dict[Any, Callable[[], Any]]:
+        def get_provider_map(cls) -> dict[Any, Callable[[], Any]]:
             provider_map = super().get_provider_map()
             provider_map[Any] = lambda: "any"
 
@@ -47,7 +47,7 @@ def test_provider_map_with_typevar() -> None:
 
     class FooFactory(DataclassFactory[Foo]):
         @classmethod
-        def get_provider_map(cls) -> Dict[Any, Callable[[], Any]]:
+        def get_provider_map(cls) -> dict[Any, Callable[[], Any]]:
             provider_map = super().get_provider_map()
             provider_map[T] = lambda: "any"
 
