@@ -1,12 +1,10 @@
-from typing import List
-
 import pytest
 
 from pydantic import BaseModel
 
 from polyfactory.exceptions import ParameterException
 from polyfactory.factories.pydantic_factory import ModelFactory
-from polyfactory.fields import Fixture, Use
+from polyfactory.fields import Use
 from polyfactory.pytest_plugin import register_fixture
 from tests.models import Person, PersonFactoryWithoutDefaults
 
@@ -53,22 +51,8 @@ def test_register_with_class_not_model_factory_error() -> None:
 
 class MyModel(BaseModel):
     best_friend: Person
-    all_friends: List[Person]
-    enemies: List[Person]
-
-
-def test_using_a_fixture_as_field_value() -> None:
-    class MyFactory(ModelFactory[MyModel]):
-        __model__ = MyModel
-
-        best_friend = Fixture(PersonFactoryFixture, name="mike")
-        all_friends = Fixture(PersonFactoryFixture, size=5)
-        enemies = Fixture(PersonFactoryFixture, size=0)
-
-    result = MyFactory.build()
-    assert result.best_friend.name == "mike"
-    assert len(result.all_friends) == 5
-    assert result.enemies == []
+    all_friends: list[Person]
+    enemies: list[Person]
 
 
 def test_using_factory_directly() -> None:
@@ -83,13 +67,3 @@ def test_using_factory_directly() -> None:
     assert result.best_friend.name == "mike"
     assert len(result.all_friends) == 5
     assert result.enemies == []
-
-
-def test_using_non_fixture_with_the_fixture_field_raises() -> None:
-    class MyFactory(ModelFactory[MyModel]):
-        __model__ = MyModel
-
-        all_friends = Fixture(123)  # type: ignore
-
-    with pytest.raises(ParameterException):
-        MyFactory.build()
